========================
``psyclone.domain.nemo``
========================

.. automodule:: psyclone.domain.nemo

   .. contents::
      :local:


Submodules
==========

.. toctree::

   psyclone.domain.nemo.nemo_constants
   psyclone.domain.nemo.transformations

.. currentmodule:: psyclone.domain.nemo


Classes
=======

- :py:class:`NemoConstants`:
  This class stores all Nemo constants.


.. autoclass:: NemoConstants
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: NemoConstants
      :parts: 1
